<?php
/**
 * Plugin Name: Ask Oracle Horoscope Plugin
 * Description: Displays horoscope information using a shortcode.
 * Version: 1.0
 * Author: Ask-Oracle.com
 */

// Register the settings
function horoscope_plugin_settings() {
    add_option('horoscope_plugin_api_key', 'demo');
    register_setting('horoscope_options_group', 'horoscope_plugin_api_key');
}
add_action('admin_init', 'horoscope_plugin_settings');

// Add settings page to the menu
function horoscope_plugin_menu() {
    add_options_page('Horoscope Plugin Settings', 'Horoscope', 'manage_options', 'horoscope-plugin', 'horoscope_plugin_page');
}
add_action('admin_menu', 'horoscope_plugin_menu');

// Settings page HTML
function horoscope_plugin_page() {
?>
<div>
    <h2>Horoscope Plugin Settings</h2>
    <form method="post" action="options.php">
        <?php settings_fields('horoscope_options_group'); ?>
        <table>
            <tr>
                <th scope="row"><label for="horoscope_plugin_api_key">API Key:</label></th>
                <td><input type="text" id="horoscope_plugin_api_key" name="horoscope_plugin_api_key" value="<?php echo get_option('horoscope_plugin_api_key'); ?>" /></td>
            </tr>
        </table>
        <?php submit_button(); ?>
    </form>
</div>
<?php
}

// The functions for fetching and displaying the horoscope remain unchanged
function fetch_horoscope($api_key, $date) {
    $url = "https://api.ask-oracle.com/v2/?key={$api_key}&dt={$date}";
    $data = file_get_contents($url);
    return json_decode($data);
}

function display_horoscope($json, $day, $sign, $category, $type) {
    $horoscope = $json->{'content'}->{$category}->{$type}->{$sign};
    $horoscope_formatted = "<strong>" . ucwords( "{$day} {$sign} {$type} {$category} horoscope" ) . "</strong> : {$horoscope}";
    return wpautop($horoscope_formatted);
}

function horoscope_shortcode($atts) {
    $atts = shortcode_atts(array(
        'sign' => 'Aries',
        'category' => 'daily',
        'type' => 'overview',
        'showPrevNext' => 'true'
    ), $atts, 'horoscope');
    $askoracle_api_key = get_option('horoscope_plugin_api_key', 'demo'); // Use the stored API key
    $current_date = new DateTime();
    $yesterday = $current_date->modify('-1 day')->format('Y-m-d');
    $tomorrow = $current_date->modify('+2 day')->format('Y-m-d');
    $output = '';
    if ($atts['showPrevNext'] === 'true') {
        $json_yesterday = fetch_horoscope($askoracle_api_key, $yesterday);
        $output .= display_horoscope($json_yesterday, 'Yesterday\'s', $atts['sign'], $atts['category'], $atts['type']);
    }
    $current_date->modify('-1 day'); // Reset current date
    $output .= display_horoscope(fetch_horoscope($askoracle_api_key, $current_date->format('Y-m-d')), 'Today\'s', $atts['sign'], $atts['category'], $atts['type']);
    if ($atts['showPrevNext'] === 'true') {
        $json_tomorrow = fetch_horoscope($askoracle_api_key, $tomorrow);
        $output .= display_horoscope($json_tomorrow, 'Tomorrow\'s', $atts['sign'], $atts['category'], $atts['type']);
    }
    return $output;
}
add_shortcode('horoscope', 'horoscope_shortcode');
?>